import java.util.Scanner;

class MinHeap {
	
	private int size;
	// Elements are stored from index 1 to size
	private int[] elements; 
	
	// Simple constructor with a fixed capacity
	public MinHeap(int max_capacity) {
		size = 0;
		elements = new int[max_capacity + 1];
	}
	
	// Return the last element in the heap array
	// We may assume that size >= 1
	public int queryLast() {
		return elements[size];
	}

	/*** Methods to implement */

	// Insert element "key" into the heap, restoring the heap property
	// You may assume that the heap array does not overflow
	public void insert(int val) {
		elements[size + 1] = val;
		size += 1;
		
		// The current position in the heap
		int pos = size;
		// Compare the position to its ancestor
		while((pos > 1) && (elements[pos] < elements[pos / 2])) {
			// Swap [pos] and [pos/2] and move to the ancestor
			swap(pos, pos / 2);
			pos = pos / 2;
		}
	}

	// Swap elements[a] and elements[b]
	private void swap(int a, int b) {
		int tmp = elements[a];
		elements[a] = elements[b];
		elements[b] = tmp;
	}
	
	// Delete and return the smallest element in the heap
	// You may assume that the heap is nonempty, so size >= 1
	public int extractMin() {
		// Remember minimum value and remove it from the heap
		int minval = elements[1];
		elements[1] = elements[size];
		size -= 1;
				
		// The current position in the heap
		int pos = 1;
		// Compare the position to its ancestor
		while(true) {
			
			// If this element has no ancestors
			if (2 * pos > size)
				break;
			
			// If this element has one ancestor
			if (2 * pos == size) {
				if (elements[pos] > elements[2 * pos])
					swap(pos, 2 * pos);
				// In any case, no more ancestors below
				break;
			}
			
			// Now 2 * pos + 1 <= size, we have two ancestors - which is the smaller one?
			if (elements[2 * pos] < elements[2 * pos + 1]) {
				// Compare and maybe swap with elements[2 * pos]
				if (elements[pos] > elements[2 * pos]) {
					swap(pos, 2 * pos);
					pos = pos * 2;
				} else break;
			} else {
				// Compare and maybe swap with elements[2 * pos + 1]
				if (elements[pos] > elements[2 * pos + 1]) {
					swap(pos, 2 * pos + 1);
					pos = pos * 2 + 1;
				} else break;
			}
		}
		
		return minval;
	}
}


/* NB: For the judge to run the program, do not modify the declaration of the class Main or
 *     method main() below. The class has to be declared as "class Main { ... }"
 *     and the method as "public static void main(String[] args) { ... }" */
class Main {

	public static void main(String[] args) {

		// Read from the standard input with java.util.Scanner
		Scanner scanner = new Scanner(System.in);
		
		// Read the number of cases and loop over the cases
		int case_no, cases = scanner.nextInt();
		for (case_no = 0; case_no < cases; case_no++) {
			// Read the input size
			int n = scanner.nextInt();
			// Create a new heap with sufficient capacity
			MinHeap heap = new MinHeap(n);
			
			// Insert n elements into the heap and output the result of every queryLast
			int i;
			for (i = 0; i < n; i++) {
				int val = scanner.nextInt();
				heap.insert(val);
				System.out.print(heap.queryLast());
				if (i < n - 1)
					System.out.print(" ");
			}
			System.out.println();
			
			// Extract the smallest element from the heap n times 
			for (i = 0; i < n; i++) {
				System.out.print(heap.extractMin());
				if (i < n - 1)
					System.out.print(" ");
			}
			System.out.println();
		}
		scanner.close();
	}
}
